@@ -53,12 +53,7 @@ class MultiplesExperimentos:
                                                    cantidad_columnas=self.cantidad_columnas,
                                                    procesar_tiempo_archivo_irregular=
                                                                self.procesar_tiempo_archivo_irregular,
-                                                   puntos_importantes=self.puntos_importantes,
-                                                   objeto_a_promediar=self.objeto_a_promediar,
-                                                   tamanio_intervalo_para_promedio=self.tamanio_intervalo_para_promedio,
-                                                   genera_matriz_recurrencia=self.genera_matriz_recurrencia,
-                                                   genera_regiones_preferidas=True,
-                                                   arreglo_regiones_preferidas=self.arreglo_regiones_preferidas))
+                                                   puntos_importantes=self.puntos_importantes))
 
         else:
             for archivo in self.lista_archivos:
